==> portal-1.1.20-201912250048-sources.jar: com/gtis/portal/entity/BdcGzlsx.java <==
package com.gtis.portal.entity;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/**
 * 工作流时间限制记录
 */
@Entity
@Table(name = "WORKFLOW_TIME")
public class BdcGzlsx implements Serializable {

    @Id
    @Column
    private  String workflow_time_id;//主键id
    @Column
    private  String dwdm;//单位代码
    @Column
    private String workflow_name;//流程名称
    @Column
    private  String workflow_id;//流程id
    @Column
    private Integer workflow_time_limit;// 流程办理时限
    @Column
    private  String sqlxdm;//申请类型代码
    @Column
    private String activity_name;//节点名称
    @Column
    private  String activity_id;//节点id
    @Column
    private Integer activity_time_limit;//节点办件时限

    public String getDwdm() {
        return dwdm;
    }

    public void setDwdm(String dwdm) {
        this.dwdm = dwdm;
    }

    public String getWorkflow_name() {
        return workflow_name;
    }

    public void setWorkflow_name(String workflow_name) {
        this.workflow_name = workflow_name;
    }

    public String getWorkflow_id() {
        return workflow_id;
    }

    public void setWorkflow_id(String workflow_id) {
        this.workflow_id = workflow_id;
    }

    public Integer getWorkflow_time_limit() {
        return workflow_time_limit;
    }

    public void setWorkflow_time_limit(Integer workflow_time_limit) {
        this.workflow_time_limit = workflow_time_limit;
    }

    public String getSqlxdm() {
        return sqlxdm;
    }

    public void setSqlxdm(String sqlxdm) {
        this.sqlxdm = sqlxdm;
    }

    public String getActivity_name() {
        return activity_name;
    }

    public void setActivity_name(String activity_name) {
        this.activity_name = activity_name;
    }

    public String getActivity_id() {
        return activity_id;
    }

    public void setActivity_id(String activity_id) {
        this.activity_id = activity_id;
    }

    public Integer getActivity_time_limit() {
        return activity_time_limit;
    }

    public void setActivity_time_limit(Integer activity_time_limit) {
        this.activity_time_limit = activity_time_limit;
    }
    public String getWorkflow_time_id() {
        return workflow_time_id;
    }

    public void setWorkflow_time_id(String workflow_time_id) {
        this.workflow_time_id = workflow_time_id;
    }

}

==> portal-1.1.23-202102252128-sources.jar: com/gtis/portal/entity/BdcGzlsx.java <==
package com.gtis.portal.entity;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/**
 * 工作流时间限制记录
 */
@Entity
@Table(name = "WORKFLOW_TIME")
public class BdcGzlsx implements Serializable {

    @Id
    @Column
    private  String workflow_time_id;//主键id
    @Column
    private  String dwdm;//单位代码
    @Column
    private String workflow_name;//流程名称
    @Column
    private  String workflow_id;//流程id
    @Column
    private String workflow_time_limit;// 流程办理时限
    @Column
    private  String sqlxdm;//申请类型代码
    @Column
    private String activity_name;//节点名称
    @Column
    private  String activity_id;//节点id
    @Column
    private String activity_time_limit;//节点办件时限

    public String getDwdm() {
        return dwdm;
    }

    public void setDwdm(String dwdm) {
        this.dwdm = dwdm;
    }

    public String getWorkflow_name() {
        return workflow_name;
    }

    public void setWorkflow_name(String workflow_name) {
        this.workflow_name = workflow_name;
    }

    public String getWorkflow_id() {
        return workflow_id;
    }

    public void setWorkflow_id(String workflow_id) {
        this.workflow_id = workflow_id;
    }

    public String getWorkflow_time_limit() {
        return workflow_time_limit;
    }

    public void setWorkflow_time_limit(String workflow_time_limit) {
        this.workflow_time_limit = workflow_time_limit;
    }

    public String getSqlxdm() {
        return sqlxdm;
    }

    public void setSqlxdm(String sqlxdm) {
        this.sqlxdm = sqlxdm;
    }

    public String getActivity_name() {
        return activity_name;
    }

    public void setActivity_name(String activity_name) {
        this.activity_name = activity_name;
    }

    public String getActivity_id() {
        return activity_id;
    }

    public void setActivity_id(String activity_id) {
        this.activity_id = activity_id;
    }

    public String getActivity_time_limit() {
        return activity_time_limit;
    }

    public void setActivity_time_limit(String activity_time_limit) {
        this.activity_time_limit = activity_time_limit;
    }
    public String getWorkflow_time_id() {
        return workflow_time_id;
    }

    public void setWorkflow_time_id(String workflow_time_id) {
        this.workflow_time_id = workflow_time_id;
    }

}
